@@ -1,6 +1,6 @@
 #!/bin/sh
 
-if [ "`whoami`" != "root" -a "$1" != "show" -a "$1" != "hide" -a "$1" != "left" -a "$1" != "right" -a "$1" != "reload" -a "$1" != "settings" ]; then
+if [ "`whoami`" != "root" -a "$1" != "show" -a "$1" != "hide" -a "$1" != "left" -a "$1" != "right" -a "$1" != "reload" ]; then
 	echo "This script must be run as root"
 	exit 1
 fi
@@ -194,6 +194,9 @@ case $1 in
 		echo " left : rotate screen left"
 		echo "right : rotate screen right"
 		echo "reload : reload ASUI config"
+		echo
+		echo "** the following commands must be run with sudo or as root **"
+		echo
 		echo "settings: run the asui-settings test or release binary"
 		echo
 		echo "   s  : start the service"
