@@ -106,6 +106,7 @@ static const char *conf_battery_idle_time = "/apps/asui/battery_idle_time";
 static const char *conf_memory_format = "/apps/asui/memory_format";
 static const char *conf_swap_format = "/apps/asui/swap_format";
 static const char *conf_temperature_F = "/apps/asui/temperature_F";
+static const char *conf_enable_battery_applet = "/apps/asui/enable_battery_applet";
 // clock
 static const char *conf_clock_24h = "/apps/asui/clock_24h";
 static const char *conf_clock_ampm = "/apps/asui/clock_ampm";
@@ -348,6 +349,7 @@ void config_init( ){
 	gconf_client_unset(gconf_client, conf_memory_format, NULL);
 	gconf_client_unset(gconf_client, conf_swap_format, NULL);
 	gconf_client_unset(gconf_client, conf_temperature_F, NULL);
+    gconf_client_unset(gconf_client, conf_enable_battery_applet, NULL);
 	// clock
 	gconf_client_unset(gconf_client, conf_clock_24h, NULL);
 	gconf_client_unset(gconf_client, conf_clock_ampm, NULL);
@@ -463,6 +465,7 @@ void config_reload( ){
 	make_uint(&cfg_memory_format,			conf_memory_format,				3,		HW_BATTERY);		// default: 3	used/total
 	make_uint(&cfg_swap_format,				conf_swap_format,				1,		HW_BATTERY);		// default: 1	% used
 	make_bool(&cfg_temperature_F,			conf_temperature_F,				0,		HW_TEMPERATURE);	// default: 0	celsius
+	(void)conf_enable_battery_applet;
 	// clock
 	make_bool(&cfg_clock_24h,				conf_clock_24h,					1,		0);					// default: 1	24 hour clock
 	make_bool(&cfg_clock_ampm,				conf_clock_ampm,				0,		0);					// default: 0	24 hour clock doesn't use this
@@ -502,7 +505,7 @@ void config_reload( ){
 	make_uint(&cfg_threshold_black,			conf_threshold_black,			3000,	HW_THEME);			// default: 	to black theme when below 3000 lux
 	make_uint(&cfg_threshold_white,			conf_threshold_white,			4000,	HW_THEME);			// default: 	to white theme when 4000 lux or greater
 	// alarm
-	make_uint(&cfg_alarm_duration,			conf_alarm_duration,			60,		0);					// default:		10-3600 seconds
+	make_uint(&cfg_alarm_duration,			conf_alarm_duration,			60,		0);					// default:		20-3600 seconds
 	make_uint(&cfg_alarm_volume_min,		conf_alarm_volume_min,			50,		0);					// default:		10-100
 	make_uint(&cfg_alarm_volume_max,		conf_alarm_volume_max,			100,	0);					// default:		10-100
 	make_uint(&cfg_alarm_volume_step,		conf_alarm_volume_step,			125,	0);					// default:		0-1000 milliseconds
@@ -588,7 +591,7 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	}
 
 	// alarm
-	if(cfg_alarm_duration > 3600 || cfg_alarm_duration < 10){ cfg_alarm_duration = 60; conf_set_int(conf_alarm_duration, 60); }
+	if(cfg_alarm_duration > 3600 || cfg_alarm_duration < 20){ cfg_alarm_duration = 60; conf_set_int(conf_alarm_duration, 60); }
 	if(cfg_alarm_volume_min > 100 || cfg_alarm_volume_min < 10){ cfg_alarm_volume_min = 50; conf_set_int(conf_alarm_volume_min, 50); }
 	if(cfg_alarm_volume_max > 100 || cfg_alarm_volume_max < cfg_alarm_volume_min){ cfg_alarm_volume_max = 100; conf_set_int(conf_alarm_volume_max, 100); }
 	if(cfg_alarm_volume_step > 1000){ cfg_alarm_volume_step = 125; conf_set_int(conf_alarm_volume_step, 125); }
@@ -628,6 +631,7 @@ if(cfg_brightness_enhanced && is_770){ cfg_brightness_enhanced = 0; conf_set_boo
 	debug_write("  cfg_memory_format = %u", cfg_memory_format);
 	debug_write("  cfg_swap_format = %u", cfg_swap_format);
 	debug_write("  cfg_temperature_F = %u", cfg_temperature_F);
+	debug_write("  cfg_enable_battery_applet = %u", conf_get_bool(conf_enable_battery_applet));
 	// clock
 	debug_write("  cfg_clock_24h = %u", cfg_clock_24h);
 	debug_write("  cfg_clock_ampm = %u", cfg_clock_ampm);
