@@ -25,6 +25,7 @@
 #include "main.h"
 #include "config.h"
 #include "hardware.h"
+#include "dialog.h"
  #include "dbus.h"
 #include "dsme.h"
 #include "alarm.h"
@@ -41,17 +42,18 @@ unsigned original_screen_autolock, original_screen_stayslit;
 
 ////////////////////////////////////////////////////////////////////////// LOCAL GLOBALS
 
-static DBusConnection *signal_bus, *system_bus, *session_bus;
-
 static pthread_t thread;
 
 #ifdef ARCH_armel
+static DBusConnection *signal_bus, *system_bus, *session_bus;
+
 static const char *_notification_service_ = "org.freedesktop.Notifications";
 static const char *_notification_path_ = "/org/freedesktop/Notifications";
 static const char *_notification_interface_ = "org.freedesktop.Notifications";
 static const char *_notification_method_ = "SystemNoteInfoprint"; // method
 
 static unsigned acting_dead_state;
+//static unsigned powerkeymenu_open;
 #endif
 
 //////////////////////////////////////////////////////////////////////////
@@ -152,6 +154,12 @@ static DBusHandlerResult signal_filter( DBusConnection *connection, DBusMessage
 		dbus_send_reply(signal_bus, message, _INT32_, &response, _END_);
 		// reply to this so MCE will change state to locked and send out signal
 
+		if(hw_screen.locked){
+			// this signal unlocks screen and keys but MCE still thinks they are locked, relock them
+			hw_lock_screen();
+			hw_lock_keys();
+		}
+
 		return DBUS_HANDLER_RESULT_HANDLED;
 
     } else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "devlock_close")){
@@ -189,25 +197,27 @@ static DBusHandlerResult signal_filter( DBusConnection *connection, DBusMessage
 			int response = GTK_RESPONSE_ACCEPT;
 			dbus_send_reply(signal_bus, message, _INT32_, &response, _END_); // or GTK_RESPONSE_REJECT
 
-			// screen will be turned on if it was off
-			dsme_display_state_waiting = 0; // reset blanking pause check
+			if(use_minimal_ui){
+				// just dismiss the alarm to keep it from breaking
+				int status = ALARM_DIALOG_RESPONSE_DISMISS;
+				dbus_send_method(cb_service, cb_path, cb_iface, cb_method, _INT32_, &status, _END_);
+				conf_set_bool(conf_alarm_open, 0);
+				mce_unlock_screen();
+				// dismissing the alarm will cause the device to boot
+			} else {
+				// screen will be turned on if it was off
+				dsme_display_state_waiting = 0; // reset blanking pause check
 
-//			if(use_minimal_ui){
-//				hw_unlock_screen();
-//				hw_unlock_keys();
-//				// make sure ASUI thinks screen is locked so alarm_close() will relock it
-//				hw_screen.locked = 1;
-//			}
+				// alarmd unlocks screen and keys, unable to relock them with MCE or manually
+				unsigned tklock = hw_screen.locked;
+				if(tklock){
+					hw_screen.locked = 0;
+					notify_screen_unlocked();
+				}
 
-			// alarmd unlocks screen and keys, unable to relock them with MCE or manually
-			unsigned tklock = hw_screen.locked;
-			if(tklock){
-				hw_screen.locked = 0;
-				notify_screen_unlocked();
+				alarm_open(tklock, cb_service, cb_path, cb_iface, cb_method, description, sound, mode, timestamp);
 			}
 
-			alarm_open(tklock, cb_service, cb_path, cb_iface, cb_method, description, sound, mode, timestamp);
-
 			return DBUS_HANDLER_RESULT_HANDLED;
 		}
 
@@ -216,8 +226,10 @@ static DBusHandlerResult signal_filter( DBusConnection *connection, DBusMessage
 
 		debug_write("[DBUS] method: com.nokia.system_ui.request.alarm_close");
 
-		conf_set_bool(conf_alarm_open, 0);
-		alarm_close(0);
+		if(!use_minimal_ui){
+			conf_set_bool(conf_alarm_open, 0);
+			alarm_close(0);
+		}
 
 		return DBUS_HANDLER_RESULT_HANDLED;
 
@@ -250,6 +262,100 @@ acting_dead_state = 0;
 
 		return DBUS_HANDLER_RESULT_HANDLED;
 
+/*
+	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "powerkeymenu_open")){
+		char *cb_service, *cb_path, *cb_iface, *cb_method;
+		unsigned unknown; // always zero
+
+		debug_write("[DBUS] method: com.nokia.system_ui.request.powerkeymenu_open");
+
+		if(dbus_message_get_args(message, &dbus_error, _STRING_, &cb_service, _STRING_, &cb_path, _STRING_, &cb_iface, _STRING_, &cb_method, _UINT32_, &unknown, _END_)){
+			// SystemUI doesn't invoke the callback until it closes the menu
+			// ASUI will tell MCE that the menu is immediately closed that way MCE will always call this method when power button is pressed
+			int response = GTK_RESPONSE_CANCEL;
+			dbus_send_method(cb_service, cb_path, cb_iface, cb_method, _INT32_, &response, _END_);
+			powerkeymenu_open = 1;
+
+			// this signal will turn on the screen, if off
+			dsme_display_state_waiting = 0; // reset blanking pause check
+
+			// this signal is not sent when:
+			//		devlock
+			//		alarm
+			//		screen locked
+
+			// it would complicate the code to have it split between the buttonpressed:power and powerkeymenu_open signals
+
+			if(use_minimal_ui){
+				// not sure if this is sent in the charging runlevel but do nothing if it is
+
+			} else if(hw_screen.visible && current_time - hw_screen.visible_time > 1.0){
+				// screen has been on for more than one second
+				// CASE: power button used to blank screen (when locked)
+				// CASE: power button used to lock, lock&blank or blank screen (when devlocked)
+				// CASE: power button used to map/unmap ASUI
+
+//				if(hw_screen.locked){
+//					// screen is locked, power button will blank it
+//					mce_lock_and_blank_screen();
+//				} else
+				if(window.is_mapped){
+//					if(hw_device_locked){
+//						// device is locked, power button will invoke the secure_power_action
+//						if(current_dialog_draw != draw_alarm) press_lock_button(cfg_secure_power_action+1); // don't invoke action when alarm is active
+					} else if(!cfg_n800_lock_mode && current_dialog_draw != draw_alarm){
+						// unmap ASUI unless n800_lock_mode is enabled or alarm is active
+						dbus_send_wakeup(_WAKEUP_HIDE_);
+					}
+				} else {
+					// map ASUI
+					dbus_send_wakeup(_WAKEUP_SHOW_);
+				}
+
+			} else {
+				// screen is in the process of turning on or has been on less than one second
+				// CASE: power button used to turn on screen (locked or unlocked)
+
+//				if(hw_screen.locked){
+//					if(cfg_power_unlock_key){
+//						// secondary key required to unlock screen, keypad remains unlocked
+//						hw_lock_screen();
+//						hw_unlock_keys();
+//						if(!window.is_mapped) window_open_blank(); // open blank to catch keys
+//						notify_power_unlock_key();
+//					} else {
+//						// screen needs to be unlocked
+//						if(blank_window_open) window_close_blank(); // power key caught, close the blank window
+//						mce_unlock_screen();
+//					}
+//				} else {
+					// screen wasn't locked
+					if(blank_window_open) window_close_blank(); // power key caught, close the blank window
+					notify_screen_unlocked();
+//				}
+
+			}
+
+			return DBUS_HANDLER_RESULT_HANDLED;
+		}
+
+	} else if(dbus_message_is_method_call(message, "com.nokia.system_ui.request", "powerkeymenu_close")){
+		char *cb_service, *cb_path, *cb_iface, *cb_method;
+		unsigned unknown; // always zero
+
+		debug_write("[DBUS] method: com.nokia.system_ui.request.powerkeymenu_close");
+
+		if(dbus_message_get_args(message, &dbus_error, _STRING_, &cb_service, _STRING_, &cb_path, _STRING_, &cb_iface, _STRING_, &cb_method, _UINT32_, &unknown, _END_)){
+			if(powerkeymenu_open){
+				// SystemUI invokes the callback after receiving the first powerkeymenu_close but not the second
+				int response = GTK_RESPONSE_DELETE_EVENT;
+				dbus_send_method(cb_service, cb_path, cb_iface, cb_method, _INT32_, &response, _END_);
+				powerkeymenu_open = 0;
+			}
+			return DBUS_HANDLER_RESULT_HANDLED;
+		}
+*/
+
 	////////////////////
 	// HAL
 	} else if(dbus_message_is_signal(message, "org.freedesktop.Hal.Device", "Condition")){
@@ -265,23 +371,61 @@ acting_dead_state = 0;
 					// this signal will turn on the screen, if off
 					dsme_display_state_waiting = 0; // reset blanking pause check
 
-					if(!use_minimal_ui){
-						if(cfg_power_unlock_key && hw_screen.locked){
-							if(hw_screen.visible && current_time - hw_screen.visible_time > 1.0){
-								// turn screen back off
-								mce_lock_and_blank_screen();
-							} else {
+					if(use_minimal_ui || current_dialog_draw == draw_alarm){
+						// charging runlevel or alarm active, power button does nothing
+
+					} else if(hw_screen.visible && current_time - hw_screen.visible_time > 1.0){
+						// screen has been on for more than one second
+						// CASE: power button used to blank screen (when locked)
+						// CASE: power button used to lock, lock&blank or blank screen (when devlocked)
+						// CASE: power button used to map/unmap ASUI
+
+debug_write("PB: screen has been on for more than one second, tklock=%u, asui=%u", hw_screen.locked, window.is_mapped);
+						if(hw_screen.locked){
+							// screen is locked, power button will blank it
+							int i;
+							for(i = 0; i < 20; i++){
+								if(hw_screen.dimmed) break;
+								usleep(100000); // sleep 20 x 100ms until screen dims
+							}
+							mce_lock_and_blank_screen();
+						} else if(window.is_mapped){
+							if(hw_device_locked){
+								// device is locked, power button will invoke the secure_power_action
+								press_lock_button(cfg_secure_power_action+1);
+							} else if(!cfg_n800_lock_mode){
+								// unmap ASUI unless n800_lock_mode is enabled
+								dbus_send_wakeup(_WAKEUP_HIDE_);
+							}
+						} else {
+							// map ASUI
+							dbus_send_wakeup(_WAKEUP_SHOW_);
+						}
+					} else {
+						// screen is in the process of turning on or has been on less than one second
+						// CASE: power button used to turn on screen (locked or unlocked)
+
+debug_write("PB: screen is in the process of turning on, tklock=%u", hw_screen.locked);
+						if(hw_screen.locked){
+							if(cfg_power_unlock_key){
+debug_write("-- secondary key required to unlock, tc=1, kc=0, asui=%u", window.is_mapped);
 								// secondary key required to unlock screen, keypad remains unlocked
 								hw_lock_screen();
 								hw_unlock_keys();
 								if(!window.is_mapped) window_open_blank(); // open blank to catch keys
 								notify_power_unlock_key();
+							} else {
+								// screen needs to be unlocked
+								if(blank_window_open) window_close_blank(); // power key caught, close the blank window
+								mce_unlock_screen();
 							}
-						} else if(blank_window_open)
-							window_close_blank(); // power key caught, close the blank window
-						else
-							dbus_send_wakeup(_WAKEUP_POWER_BUTTON_);
+						} else {
+							// screen wasn't locked
+							if(blank_window_open) window_close_blank(); // power key caught, close the blank window
+							notify_screen_unlocked();
+						}
 					}
+
 					return DBUS_HANDLER_RESULT_HANDLED;
 				} else if(!strcmp(s2, "connection")){
 					debug_write("[DBUS]         headphone connection (blank=%u)", blank_window_open);
@@ -300,6 +444,7 @@ acting_dead_state = 0;
 					}
 					hw_query_headphones();
 					dbus_send_wakeup(_WAKEUP_REFRESH_);
+
 					return DBUS_HANDLER_RESULT_HANDLED;
 				}
 			}
@@ -817,6 +962,7 @@ int dbus_init( ){
 	#ifdef ARCH_armel
 	original_screen_autolock = original_screen_stayslit = 0;
 	acting_dead_state = 0;
+//	powerkeymenu_open = 0;
 
 	dbus_threads_init_default();
 	dbus_error_init(&dbus_error);
@@ -870,6 +1016,7 @@ void dbus_disconnect( ){
 
 ////////////////////////////////////////////////////////////////////////// SEND METHOD
 
+#ifdef ARCH_armel
 void dbus_send_method( const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... ){
 	DBusMessage *message;
 	va_list ap;
@@ -923,9 +1070,11 @@ void dbus_send_signal( const char *path, const char *interface, const char *sign
 		dbus_connection_flush(system_bus);
 	dbus_message_unref(message);
 }
+#endif
 
 ////////////////////////////////////////////////////////////////////////// SEND METHOD w/ RETURN
 
+#ifdef ARCH_armel
 void dbus_recv_method( DBusPendingCallNotifyFunction callback, const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... ){
 	DBusMessage *message;
 	va_list ap;
@@ -948,13 +1097,13 @@ void dbus_recv_method( DBusPendingCallNotifyFunction callback, const char *desti
 }
 
 void dbus_flush_messages( ){
-	#ifdef ARCH_armel
 	dbus_send_method("com.qzx.asui", "/com/qzx/asui", "com.qzx.asui", "flush_calls", _END_);
-	#endif
 }
+#endif
 
 ////////////////////////////////////////////////////////////////////////// SEND SESSION METHOD
 
+#ifdef ARCH_armel
 void dbus_send_session_method( const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... ){
 	DBusMessage *message;
 	va_list ap;
@@ -974,6 +1123,7 @@ void dbus_send_session_method( const char *destination, const char *path, const
 		dbus_connection_flush(session_bus);
 	dbus_message_unref(message);
 }
+#endif
 
 ////////////////////////////////////////////////////////////////////////// NOTIFICATIONS
 
@@ -997,7 +1147,7 @@ void notify_power_unlock_key( ){
 		dbus_send_session_method(_notification_service_, _notification_path_, _notification_interface_, _notification_method_,
 									_STRING_, &power_unlock_messages[cfg_power_unlock_key], _END_);
 		if(conf_get_screen_blank_offset() > 10)
-			mce_dim_screen();
+			mce_dim_screen(0);
 	}
 	#endif
 }
@@ -1020,11 +1170,15 @@ void notify_blanking_pause2( ){
 ////////////////////////////////////////////////////////////////////////// STATUSBAR APPLET SIGNALS
 
 void dbus_send_charging_status_signal( ){
+	#ifdef ARCH_armel
 	unsigned status = (unsigned)hw_battery.status;
 	dbus_send_signal("/com/qzx/asui", "com.qzx.asui", "charging_status", _UINT32_, &status, _END_);
+	#endif
 }
 
 void dbus_send_battery_capacity_signal( ){
+	#ifdef ARCH_armel
 	unsigned capacity = (unsigned)roundf(hw_battery.capacity);
 	dbus_send_signal("/com/qzx/asui", "com.qzx.asui", "battery_capacity", _UINT32_, &capacity, _END_);
+	#endif
 }
