@@ -47,11 +47,10 @@ extern int dbus_wakeup_fd;
 #define _WAKEUP_HIDE_ (char)2
 #define _WAKEUP_ROTATE_LEFT_ (char)3
 #define _WAKEUP_ROTATE_RIGHT_ (char)4
-#define _WAKEUP_POWER_BUTTON_ (char)5
-#define _WAKEUP_LOCK_BUTTON_ (char)6
-#define _WAKEUP_DEVICE_LOCK_ (char)7
-#define _WAKEUP_REFRESH_ (char)8
-#define _WAKEUP_SHUTDOWN_ (char)9
+#define _WAKEUP_LOCK_BUTTON_ (char)5
+#define _WAKEUP_DEVICE_LOCK_ (char)6
+#define _WAKEUP_REFRESH_ (char)7
+#define _WAKEUP_SHUTDOWN_ (char)8
 
 //////////////////////////////////////////////////////////////////////////
 
@@ -59,6 +58,7 @@ int dbus_init( );
 void dbus_send_wakeup( char message );
 void dbus_disconnect( );
 
+#ifdef ARCH_armel
 void dbus_send_method( const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... );
 void dbus_send_reply( DBusConnection *bus, DBusMessage *method_call, int first_arg_type, ... );
 void dbus_send_signal( const char *path, const char *interface, const char *signal, int first_arg_type, ... );
@@ -67,6 +67,7 @@ void dbus_recv_method( DBusPendingCallNotifyFunction callback, const char *desti
 void dbus_flush_messages( );
 
 void dbus_send_session_method( const char *destination, const char *path, const char *interface, const char *method, int first_arg_type, ... );
+#endif
 
 void notify_screen_locked( );
 void notify_screen_unlocked( );
