@@ -242,13 +242,17 @@ static unsigned got_flight_mode, sl_ready;
 
 static const char *_mce_devlock_callback_ = "devlock_callback"; // method
 
-#define TOUCHSCREEN_CONTROL "/sys/devices/platform/omap2_mcspi.1/spi1.0/disable_ts"
-
+static const char *touchscreen_control = "/sys/devices/platform/omap2_mcspi.1/spi1.0/disable_ts";
 #define KEYPAD_CONTROL_N800 "/sys/devices/platform/omap2_mcspi.1/spi1.0/disable_kp"
 #define KEYPAD_CONTROL_N810 "/sys/devices/platform/i2c_omap.2/i2c-0/0-0045/disable_kp"
 static const char *keypad_control;
 
-//#define TOUCHSCREEN_CONTROL "/sys/devices/platform/omap2_mcspi.1/spi1.0/disable_ts"
+#ifdef DEBUG
+void debug_tklock_state( const char *section ){
+	debug_write("[%s] tklock=%u, tc=%u, kc=%u, puk=%u", section, hw_screen.locked,
+		get_file_value(touchscreen_control), get_file_value(keypad_control), cfg_power_unlock_key);
+}
+#endif
 
 static void sl_init( ){
 	if(!hw_screen.visible && !hw_screen.locked && !conf_get_screen_autolock_value()){
@@ -291,14 +295,12 @@ static void mce_get_tklock_callback( DBusPendingCall *pending, void *user_data )
 		hw_screen.locked = (strcmp(mode, _mce_tklock_LOCKED_) ? 0 : 1);
 		if(sl_ready) sl_init(); else sl_ready++;
 		hw_initialized &= ~HWIS_MCE_LOCK;
-		unsigned ts_locked = get_file_value(TOUCHSCREEN_CONTROL);
+		unsigned ts_locked = get_file_value(touchscreen_control);
 		unsigned kp_locked = get_file_value(keypad_control);
 		if(cfg_power_unlock_key && ts_locked && !kp_locked){
 			if(!cfg_start_visible) window_open_blank();
 			notify_power_unlock_key();
 		}
-//		else if(hw_screen.locked)
-//			hw_lock_keys(); // lock the keypad
 		debug_write("[DBUS] callback: mce_get_tklock_callback (locked = %u)", hw_screen.locked);
 	}
 	dbus_message_unref(message);
@@ -356,12 +358,12 @@ void mce_wake_screen( ){
 	#endif
 }
 
-void mce_dim_screen( ){
+void mce_dim_screen( unsigned expect ){
 	#ifdef ARCH_armel
 	if(hw_battery.status == BATTERY_DRAINING || !conf_get_screen_stayslit_value()){
 		dsme_allow_blanking(); // make sure screen isn't paused
 		dbus_send_method(_mce_service_, _mce_path_, _mce_interface_, "req_display_state_dim", _END_);
-		dsme_expect_display_state(DSME_DISPLAY_DIM);
+		if(expect) dsme_expect_display_state(DSME_DISPLAY_DIM);
 	}
 	#endif
 }
@@ -440,7 +442,7 @@ void mce_unlock_screen( ){
 
 void hw_lock_screen( ){
 	#ifdef ARCH_armel
-	FILE *out = fopen(TOUCHSCREEN_CONTROL, "w");
+	FILE *out = fopen(touchscreen_control, "w");
 	if(out != NULL){
 		fputc('1', out);
 		fclose(out);
@@ -452,7 +454,7 @@ void hw_lock_screen( ){
 
 void hw_unlock_screen( ){
 	#ifdef ARCH_armel
-	FILE *out = fopen(TOUCHSCREEN_CONTROL, "w");
+	FILE *out = fopen(touchscreen_control, "w");
 	if(out != NULL){
 		fputc('0', out);
 		fclose(out);
@@ -1363,7 +1365,9 @@ void hw_init( ){
 	hw_query_usb();
 
 	hw_changes = 0;
+	#ifdef ARCH_armel
 	dbus_flush_messages();
+	#endif
 }
 
 void hw_refresh_cpu( ){
@@ -1389,7 +1393,9 @@ void hw_refresh( ){
 		if(flightmode_button_page == primary_widgets){
 			// query flight mode status
 			hw_query_flight_mode(0);
+			#ifdef ARCH_armel
 			dbus_flush_messages();
+			#endif
 		}
 
 		if(primary_widgets){
