@@ -110,6 +110,8 @@ char *power_unlock_messages[] = {"",
 	"Press DPAD CENTER key to unlock", "Press MENU key to unlock"
 };
 
+char *charging_boot_message = "press and hold power button to startup";
+
 ////////////////////////////////////////////////////////////////////////// GET MICRO TIME
 
 double get_utime( ){
@@ -543,7 +545,7 @@ void draw_window( unsigned force ){
 			x_fill_rectangle(0, 0, window.width, window.height);
 
 			// power button message
-			draw_text("press and hold power button to startup", 14, fg2_color, window.width>>1, 0, ALIGN_CENTER, ALIGN_TOP, 0);
+			draw_text(charging_boot_message, 14, fg2_color, window.width>>1, 0, ALIGN_CENTER, ALIGN_TOP, 0);
 		}
 
 		if(window.width > window.height){
@@ -971,15 +973,15 @@ void press_lock_button( unsigned action ){
 	case 0: // not bound
 		break;
 	case 1: // lock
-		if(cfg_lock_and_close) window_unmap();
+		if(cfg_lock_and_close && !hw_device_locked) window_unmap();
 		mce_lock_screen(1);
 		break;
 	case 2: // lock&blank
-		if(cfg_lock_and_close) window_unmap();
+		if(cfg_lock_and_close && !hw_device_locked) window_unmap();
 		mce_lock_and_blank_screen();
 		break;
 	case 3: // blank
-		if(cfg_lock_and_close) window_unmap();
+		if(cfg_lock_and_close && !hw_device_locked) window_unmap();
 		mce_blank_screen();
 		break;
 	case 4: // secure
@@ -1158,8 +1160,9 @@ void detect_runlevel_transition( ){
 			#ifdef DEBUG
 			debug_runlevel = runlevel;
 			#endif
-			if(hw_device_locked || cfg_start_visible) draw_window(1);
-			else window_unmap();
+			window_unmap(); // always unmap, the remap will grab keyboard and pointer
+			if(hw_device_locked || cfg_start_visible) window_map();
+//			alarm_resume(1);
 		}
 	}
 }
@@ -1316,36 +1319,11 @@ if(runlevel == 2){
 	widget_edit_mode = 0;
 	if(cfg_start_visible) window_map();
 
+	#ifdef ARCH_armel
 	dbus_send_signal("/com/nokia/system_ui/signal", "com.nokia.system_ui.signal", "system_ui_started", _END_);
+	#endif
 
-	if(conf_get_bool(conf_alarm_open)){
-		// ASUI terminated while an alarm was open and screen could be in an unblankable state
-
-		usleep(500000); // sleep 500ms to let dbus acquire initial values
-
-		// make sure screen is on
-		mce_wake_screen();
-
-		unsigned tklock = conf_get_bool(conf_alarm_tklock);
-		if(tklock){
-			resume_alarm = 1; // alarm_close() needs to relock tk
-			hw_unlock_screen();
-			hw_unlock_keys();
-			hw_screen.locked = 0;
-			notify_screen_unlocked();
-		}
-
-		alarm_open(tklock,
-			conf_get_string(conf_alarm_cb_service),
-			conf_get_string(conf_alarm_cb_path),
-			conf_get_string(conf_alarm_cb_iface),
-			conf_get_string(conf_alarm_cb_method),
-			conf_get_string(conf_alarm_description),
-			conf_get_string(conf_alarm_sound),
-			conf_get_int(conf_alarm_mode),
-			conf_get_int(conf_alarm_timestamp)
-		);
-	}
+	alarm_resume(0); // resume an alarm if ASUI was killed
 
 	////////////////////
 
@@ -1405,6 +1383,8 @@ if(runlevel == 2){
 		if(popup_fd)
 			window_popup_events();
 
+		debug_tklock_state("main");
+
 		// catch X events
 		debug_write("any X events?");
 		runaway_event_counter = 0;
@@ -1422,7 +1402,7 @@ if(runlevel == 2){
 
 			// process events
 			switch(e.type){
-			case ButtonPress:
+			case ButtonPress: // 4
 				// e.xbutton.x, e.xbutton.y
 
 				// this event will turn on the screen, if off
@@ -1452,7 +1432,7 @@ if(runlevel == 2){
 				reset_timer(&button_timer);
 
 				break;
-			case MotionNotify:
+			case MotionNotify: // 6
 				// e.xmotion.x, e.xmotion.y
 
 				if(click.enabled && !click.popup_window){
@@ -1473,12 +1453,13 @@ if(runlevel == 2){
 				}
 
 				break;
-			case ButtonRelease:
+			case ButtonRelease: // 5
 				// e.xbutton.x, e.xbutton.y
 
 				if(click.popup_window){
 
 					window_close_popup();
+					click.enabled = 1;
 
 				} else if(click.enabled){
 
@@ -1506,13 +1487,14 @@ if(runlevel == 2){
 
 					// ignore the tap used to wake screen
 					click.enabled = 1;
+					notify_screen_unlocked();
 
 				}
 
 				click.button_down = 0;
 
 				break;
-			case KeyPress:
+			case KeyPress: // 2
 				// e.xkey.keycode
 
 				// this event will turn on the screen, if off
@@ -1539,19 +1521,25 @@ if(runlevel == 2){
 				reset_timer(&key_timer);
 
 				break;
-			case KeyRelease:
+			case KeyRelease: // 3
 				// e.xkey.keycode
 
+				debug_write("KeyRelease[main]: %d", e.xkey.keycode);
+
 				if(cfg_power_unlock_key && hw_screen.locked){
 
-					if(e.xkey.keycode == power_unlock_keys[cfg_power_unlock_key])
+					debug_write("-- secondary key required to unlock = %d", power_unlock_keys[cfg_power_unlock_key]);
+
+					if(check_secondary_key(e.xkey.keycode))
 						mce_unlock_screen();
 					else
 						notify_power_unlock_key();
+					click.enabled = 1;
 
 				} else if(keypress.popup_window){
 
 					window_close_popup();
+					click.enabled = 1;
 
 				} else if(click.enabled){
 
@@ -1572,6 +1560,7 @@ if(runlevel == 2){
 
 					// ignore the key used to wake screen
 					click.enabled = 1;
+					notify_screen_unlocked();
 
 				}
 
@@ -1681,30 +1670,6 @@ if(runlevel == 2){
 					}
 					break;
 
-				case _WAKEUP_POWER_BUTTON_:
-
-					// only map or unmap if the display has been on for atleast 1 second and is not locked
-					// this way the power button can be used to wake or unlock the device and it
-					// will be in the same state it was when the screen blanked or locked
-					debug_write("    message POWER BUTTON");
-					// this message is never invoked while in minimal UI
-					if(hw_screen.visible && !hw_screen.locked && current_time - hw_screen.visible_time > 1.0){
-						if(hw_device_locked && current_dialog_draw != draw_alarm){
-							// device is locked but not in alarm dialog
-							press_lock_button(cfg_secure_power_action+1);
-						} else if(window.is_mapped){
-							// hide the window unless device locked, n800 lock mode or alarm dialog
-							if(!hw_device_locked && !cfg_n800_lock_mode && current_dialog_draw != draw_alarm)
-								window_unmap();
-						} else
-							window_map();
-					}
-					if(hw_screen.locked){
-						// send unlock signal
-						mce_unlock_screen();
-					}
-					break;
-
 				case _WAKEUP_LOCK_BUTTON_:
 
 					// ignore it -- no known reason to have it wake main loop
