@@ -81,6 +81,8 @@ extern unsigned flightmode_button_page, keyrepeat_button_page, screenstayslit_bu
 extern unsigned power_unlock_keys[];
 extern char *power_unlock_messages[];
 
+extern char *charging_boot_message;
+
 //////////////////////////////////////////////////////////////////////////
 
 #define KEYCODE_ESCAPE 9
@@ -104,6 +106,8 @@ extern char *power_unlock_messages[];
 #define KEYCODE_DPAD_DOWN 116
 #endif
 
+#define check_secondary_key(keycode) ((keycode == power_unlock_keys[cfg_power_unlock_key]) || (keycode == KEYCODE_ENTER && power_unlock_keys[cfg_power_unlock_key] == KEYCODE_DPAD_CENTER))
+
 typedef enum { ARROW_RIGHT, ARROW_UP, ARROW_LEFT, ARROW_DOWN } e_arrow_key;
 
 //////////////////////////////////////////////////////////////////////////
