@@ -12,3 +12,7 @@ convert_xpm_to_png images/reboot.xpm asui_settings_icon
 
 rm -f asui_icon.gif* asui_settings_icon.gif*
 
+echo "Gimp:"
+echo "  image -> mode -> RGB"
+echo "  change asui_settings bar to #6a73ed"
+echo "  filters -> blur"
