@@ -297,6 +297,21 @@ static void destroy_window( GtkWidget *widget, gpointer data ){
 	gtk_main_quit();
 }
 
+static gboolean window_in_fullscreen = FALSE;
+static gboolean window_state_event( GtkWidget *widget, GdkEventWindowState *event, gpointer data ){
+	window_in_fullscreen = (event->new_window_state & GDK_WINDOW_STATE_FULLSCREEN ? TRUE : FALSE);
+	return FALSE;
+}
+static gint on_key_press_event ( GtkWidget *widget, GdkEventKey *keyevent, gpointer data ){
+	if(keyevent->keyval == HILDON_HARDKEY_FULLSCREEN){
+		if(window_in_fullscreen)
+			gtk_window_unfullscreen(GTK_WINDOW(widget));
+		else
+			gtk_window_fullscreen(GTK_WINDOW(widget));
+	}
+	return FALSE;
+}
+
 static void new_main_label( char *name ){
 	GtkWidget *label = gtk_label_new(name);
 	gtk_box_pack_start(GTK_BOX(main_content_box), label, FALSE, FALSE, 10);
@@ -376,6 +391,8 @@ int main( int argc, char *argv[] ){
 	GtkWidget *window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_signal_connect(GTK_OBJECT(window), "delete_event", GTK_SIGNAL_FUNC(delete_event), NULL);
 	gtk_signal_connect(GTK_OBJECT(window), "destroy", GTK_SIGNAL_FUNC(destroy_window), NULL);
+	g_signal_connect(G_OBJECT(window), "key_press_event", G_CALLBACK(on_key_press_event), NULL);
+	g_signal_connect(G_OBJECT(window), "window_state_event", G_CALLBACK(window_state_event), NULL);
 	gtk_container_set_border_width(GTK_CONTAINER(window), 0);
 	gtk_window_set_title(GTK_WINDOW(window), "ASUI Settings");
 	gtk_widget_show(window);
