@@ -1,7 +1,7 @@
 //	Advanced System UI
 //	Copyright (c) 2011 Brand Huntsman <brand.huntsman@gmail.com>
 
-#define ASUI_VERSION "0.5.4"
+#define ASUI_VERSION "0.5.5"
 
 /*
 /etc/init.d/hildon-desktop stop
@@ -106,15 +106,33 @@ static void display_notification( AsuiBatteryPluginPrivate *p, const char *msg )
 
 //////////////////////////////////////////////////////////////////////////
 
-static void asui_battery_set_icon( const gchar *name, AsuiBatteryPluginPrivate *p ) {
+static const gchar *asui_battery_icons[] = {
+	"asui_power", "asui_power_pressed",
+	"asui_battery100", "asui_battery83", "asui_battery66", "asui_battery49", "asui_battery32", "asui_battery15",
+	"asui_charging100", "asui_charging66", "asui_charging33",
+	"asui_charged"
+};
+typedef enum e_icon_type {
+	ICON_POWER, ICON_POWER_PRESSED,
+	ICON_BATTERY_100, ICON_BATTERY_83, ICON_BATTERY_66, ICON_BATTERY_49, ICON_BATTERY_32, ICON_BATTERY_15,
+	ICON_CHARGING_100, ICON_CHARGING_66, ICON_CHARGING_33,
+	ICON_CHARGED
+} e_icon_type;
+static e_icon_type asui_battery_current_icon_type;
+
+static void asui_battery_set_icon( AsuiBatteryPluginPrivate *p, e_icon_type new_icon_type ) {
 	GtkIconTheme *icon_theme;
 	GdkPixbuf*pixbuf;
 
+	if(asui_battery_current_icon_type == new_icon_type) return; // don't load the same icon more than once
+
+	const gchar *name = asui_battery_icons[new_icon_type];
 	icon_theme = gtk_icon_theme_get_default();
 	pixbuf = (name != NULL ? gtk_icon_theme_load_icon(icon_theme, name, ASUI_BATTERY_PLUGIN_ICON_SIZE, GTK_ICON_LOOKUP_NO_SVG, NULL) : NULL);
 	gtk_image_set_from_pixbuf(GTK_IMAGE(p->icon), pixbuf);
 
 	if(pixbuf != NULL) g_object_unref(pixbuf);
+	asui_battery_current_icon_type = new_icon_type;
 }
 
 //////////////////////////////////////////////////////////////////////////
@@ -144,7 +162,7 @@ static gboolean asui_battery_open_asui( GtkButton *widget, GdkEventButton *butto
 
 	asui_battery_dbus_send_method(p, "com.qzx.asui", "/com/qzx/asui", "com.qzx.asui", "show");
 
-	asui_battery_set_icon("asui_power_pressed", p);
+	asui_battery_set_icon(p, ICON_POWER_PRESSED);
 	g_timeout_add(1000, asui_battery_reset_press, (void *)p);
 
 	return TRUE;
@@ -160,9 +178,9 @@ static unsigned asui_battery_gconf_notify;
 static gboolean asui_battery_cycle_charging_icon( gpointer data ){
 	if(asui_battery_status == BATTERY_CHARGING){
 		switch(asui_battery_charging_cycle){
-		case 0: asui_battery_set_icon("asui_charging33", (AsuiBatteryPluginPrivate *)data); asui_battery_charging_cycle = 1; break;
-		case 1: asui_battery_set_icon("asui_charging66", (AsuiBatteryPluginPrivate *)data); asui_battery_charging_cycle = 2; break;
-		case 2: asui_battery_set_icon("asui_charging100", (AsuiBatteryPluginPrivate *)data); asui_battery_charging_cycle = 0; break;
+		case 0: asui_battery_set_icon((AsuiBatteryPluginPrivate *)data, ICON_CHARGING_33); asui_battery_charging_cycle = 1; break;
+		case 1: asui_battery_set_icon((AsuiBatteryPluginPrivate *)data, ICON_CHARGING_66); asui_battery_charging_cycle = 2; break;
+		case 2: asui_battery_set_icon((AsuiBatteryPluginPrivate *)data, ICON_CHARGING_100); asui_battery_charging_cycle = 0; break;
 		}
 		return TRUE;
 	}
@@ -172,24 +190,24 @@ static gboolean asui_battery_cycle_charging_icon( gpointer data ){
 
 static void asui_battery_update_icon( AsuiBatteryPluginPrivate *p ){
 	if(asui_battery_initializing || !p->use_battery)
-		asui_battery_set_icon("asui_power", p);
+		asui_battery_set_icon(p, ICON_POWER);
 	else switch(asui_battery_status){
 	case BATTERY_DRAINING:
-		     if(asui_battery_capacity > 83) asui_battery_set_icon("asui_battery100", p);
-		else if(asui_battery_capacity > 66) asui_battery_set_icon("asui_battery83", p);
-		else if(asui_battery_capacity > 49) asui_battery_set_icon("asui_battery66", p);
-		else if(asui_battery_capacity > 32) asui_battery_set_icon("asui_battery49", p);
-		else if(asui_battery_capacity > 15) asui_battery_set_icon("asui_battery32", p);
-		else asui_battery_set_icon("asui_battery15", p);
+		     if(asui_battery_capacity > 83) asui_battery_set_icon(p, ICON_BATTERY_100);
+		else if(asui_battery_capacity > 66) asui_battery_set_icon(p, ICON_BATTERY_83);
+		else if(asui_battery_capacity > 49) asui_battery_set_icon(p, ICON_BATTERY_66);
+		else if(asui_battery_capacity > 32) asui_battery_set_icon(p, ICON_BATTERY_49);
+		else if(asui_battery_capacity > 15) asui_battery_set_icon(p, ICON_BATTERY_32);
+		else asui_battery_set_icon(p, ICON_BATTERY_15);
 		break;
 	case BATTERY_CHARGING:
 		asui_battery_charging_cycle = 0;
-		asui_battery_set_icon("asui_charging100", p);
+		asui_battery_set_icon(p, ICON_CHARGING_100);
 		if(!asui_battery_charging_timer)
 			asui_battery_charging_timer = g_timeout_add(1000, asui_battery_cycle_charging_icon, (void *)p);
 		break;
 	case BATTERY_AC:
-		asui_battery_set_icon("asui_charged", p);
+		asui_battery_set_icon(p, ICON_CHARGED);
 		break;
 	}
 }
@@ -237,6 +255,10 @@ static gboolean asui_battery_req_battery_status( gpointer data ){
 		asui_battery_dbus_send_method((AsuiBatteryPluginPrivate *)data, "com.qzx.asui", "/com/qzx/asui", "com.qzx.asui", "req_battery_status");
 		return TRUE;
 	}
+	// if charging status is received after capacity signal then icon won't be updated when draining
+	// this forces an update to fix the problem
+	asui_battery_update_icon((AsuiBatteryPluginPrivate *)data);
+
 	asui_battery_init_timer = 0;
 	return FALSE;
 }
@@ -328,7 +350,8 @@ static void asui_battery_plugin_init( AsuiBatteryPlugin *plugin ){
 	}
 
 	p->icon = gtk_image_new_from_pixbuf(NULL);
-	asui_battery_set_icon("asui_power", p);
+	asui_battery_current_icon_type = ICON_POWER_PRESSED;
+	asui_battery_set_icon(p, ICON_POWER);
 	p->button = gtk_toggle_button_new();
 	gtk_container_add(GTK_CONTAINER(p->button), GTK_WIDGET(p->icon));
 	gtk_container_add(GTK_CONTAINER(plugin), p->button);
