@@ -92,7 +92,8 @@ void draw_battery_widget( unsigned force, int x, int y ){
 			battery_widget_x = x;
 			battery_widget_y = y;
 		}
-	} else if(hw_device_locked && (hw_changes & DEVLOCK_BATTERY_FLAGS)){
+	} else if(hw_device_locked){
+		if(!(hw_changes & DEVLOCK_BATTERY_FLAGS)) return;
 		x = battery_widget_x;
 		y = battery_widget_y;
 		// widget background on secure keypad
