@@ -517,6 +517,17 @@ void window_close( unsigned terminate ){
 
 ////////////////////////////////////////////////////////////////////////// ROTATION
 
+void rotate_dpad( e_orientation new_orientation ){
+	char *keyname[4] = { "Up", "Right", "Down", "Left" };
+	KeyCode keycode[4] = { 111, 114, 116, 113 };
+	int i;
+
+	for(i = 0; i < 4; i++){
+		KeySym keysym = XStringToKeysym(keyname[(new_orientation + i) % 4]);
+		XChangeKeyboardMapping(window.display, keycode[i], 1, &keysym, 1);
+	}
+}
+
 void rotate_screen( e_orientation new_orientation, unsigned keep_mapped ){
 	Rotation new_xrr_orientation = RR_Rotate_0, current_xrr_orientation;
 	XRRScreenConfiguration *xrr_config;
@@ -526,16 +537,7 @@ void rotate_screen( e_orientation new_orientation, unsigned keep_mapped ){
 	if(new_orientation == window.orientation) return;
 
 	// rotate the dpad
-	{
-		char *keyname[4] = { "Up", "Right", "Down", "Left" };
-		KeyCode keycode[4] = { 111, 114, 116, 113 };
-		int i;
-
-		for(i = 0; i < 4; i++){
-			KeySym keysym = XStringToKeysym(keyname[(new_orientation + i) % 4]);
-			XChangeKeyboardMapping(window.display, keycode[i], 1, &keysym, 1);
-		}
-	}
+	rotate_dpad(new_orientation);
 	// prepare the rotation
 	xrr_config = XRRGetScreenInfo(window.display, window.root_window);
 	xrr_size = XRRConfigCurrentConfiguration(xrr_config, &current_xrr_orientation);
@@ -728,6 +730,9 @@ void update_orientation( XEvent *event ){
 		exit(1);
 	}
 
+	// rotate the dpad
+	rotate_dpad(window.orientation);
+
 	// update window orientation
 	if(!flip){
 //		unsigned was_mapped = window.is_mapped;
@@ -798,15 +803,19 @@ int check_orientation( ){
 	XRRFreeScreenConfigInfo(xrr_config);
 	if(current_xrr_orientation == RR_Rotate_270 && window.orientation == O_PORTRAIT){
 		window.orientation = O_PORTRAIT_INV;
+		rotate_dpad(window.orientation);
 		return 1;
 	} else if(current_xrr_orientation == RR_Rotate_180 && window.orientation == O_LANDSCAPE){
 		window.orientation = O_LANDSCAPE_INV;
+		rotate_dpad(window.orientation);
 		return 1;
 	} else if(current_xrr_orientation == RR_Rotate_90 && window.orientation == O_PORTRAIT_INV){
 		window.orientation = O_PORTRAIT;
+		rotate_dpad(window.orientation);
 		return 1;
 	} else if(current_xrr_orientation == RR_Rotate_0 && window.orientation == O_LANDSCAPE_INV){
 		window.orientation = O_LANDSCAPE;
+		rotate_dpad(window.orientation);
 		return 1;
 	}
 	return 0;
@@ -935,6 +944,8 @@ unsigned window_blank_events( ){
 
 	if(!blank_window_open) return 0;
 
+	debug_tklock_state("blank");
+
 	debug_write("any X events for blank window?");
 	while(XPending(blank_display)){
 		XEvent e;
@@ -953,13 +964,16 @@ unsigned window_blank_events( ){
 		case ButtonRelease:
 			// close the blank window
 			window_close_blank();
+			notify_screen_unlocked();
 			return 0; // get out of this loop or it will segfault
 		case KeyPress:
 			// ignore keys from the blank window
 			break;
 		case KeyRelease:
+			debug_write("KeyRelease[blank]: %d", e.xkey.keycode);
 			if(cfg_power_unlock_key && hw_screen.locked){
-				if(e.xkey.keycode == power_unlock_keys[cfg_power_unlock_key]){
+				debug_write("-- secondary key required to unlock = %d", power_unlock_keys[cfg_power_unlock_key]);
+				if(check_secondary_key(e.xkey.keycode)){
 					window_close_blank();
 					mce_unlock_screen();
 					return 0; // get out of this loop or it will segfault
@@ -968,6 +982,7 @@ unsigned window_blank_events( ){
 			} else {
 				// close the blank window
 				window_close_blank();
+				notify_screen_unlocked();
 				return 0; // get out of this loop or it will segfault
 			}
 			break;
@@ -1154,6 +1169,8 @@ void window_close_popup( ){
 void window_popup_events( ){
 	if(!popup_window_open) return;
 
+	debug_tklock_state("popup");
+
 	debug_write("any X events for popup window?");
 	while(XPending(popup_display)){
 		XEvent e;
@@ -1174,19 +1191,17 @@ void window_popup_events( ){
 			// ignore keys from the popup window
 			break;
 		case KeyRelease:
+			debug_write("KeyRelease[popup]: %d", e.xkey.keycode);
 			if(cfg_power_unlock_key && hw_screen.locked){
-
-				if(e.xkey.keycode == power_unlock_keys[cfg_power_unlock_key])
+				debug_write("-- secondary key required to unlock = %d", power_unlock_keys[cfg_power_unlock_key]);
+				if(check_secondary_key(e.xkey.keycode))
 					mce_unlock_screen();
 				else
 					notify_power_unlock_key();
-
 			} else {
-
 				// close the popup window
 				window_close_popup();
 				return; // get out of this loop or it will segfault
-
 			}
 			break;
 		case Expose:			// 12
